@@ -34,14 +34,13 @@ display = adafruit_il0398.IL0398(
 
 g = displayio.Group()
 
-f = open("/display-ruler.bmp", "rb")
+with open("/display-ruler.bmp", "rb") as f:
+    pic = displayio.OnDiskBitmap(f)
+    t = displayio.TileGrid(pic, pixel_shader=displayio.ColorConverter())
+    g.append(t)
 
-pic = displayio.OnDiskBitmap(f)
-t = displayio.TileGrid(pic, pixel_shader=displayio.ColorConverter())
-g.append(t)
+    display.show(g)
 
-display.show(g)
+    display.refresh()
 
-display.refresh()
-
-time.sleep(120)
+    time.sleep(120)
